@@ -10,13 +10,11 @@ use std::{
 use clap::{crate_version, value_t, values_t, App, Arg};
 use color_eyre::eyre::{Context, Report, Result};
 use log::LevelFilter;
-use watchexec::{
-    config::{Config, ConfigBuilder},
-    run::OnBusyUpdate,
-    Shell,
-};
+use watchexec::{config::ConfigBuilder, run::OnBusyUpdate, Shell};
 
-pub fn get_args() -> Result<(Config, LevelFilter)> {
+use crate::handler::CliHandler;
+
+pub fn get_args() -> Result<CliHandler> {
     let app = App::new("watchexec")
         .version(crate_version!())
         .about("Execute commands when watched files change")
@@ -133,7 +131,11 @@ pub fn get_args() -> Result<(Config, LevelFilter)> {
         .arg(Arg::with_name("watch-when-idle")
                  .help("Deprecated alias for --on-busy-update=do-nothing, which will become the default in 2.0.")
                  .short("W")
-                 .long("watch-when-idle"));
+                 .long("watch-when-idle"))
+        .arg(Arg::with_name("notif")
+                 .help("Send a desktop notification when watchexec notices a change (experimental, behaviour may change)")
+                 .short("N")
+                 .long("notify"));
 
     let mut raw_args: Vec<OsString> = env::args_os().collect();
 
@@ -281,7 +283,7 @@ pub fn get_args() -> Result<(Config, LevelFilter)> {
         LevelFilter::Warn
     };
 
-    Ok((config, loglevel))
+    CliHandler::new(config, loglevel, args.is_present("notif"))
 }
 
 // until 2.0
