@@ -1,19 +1,20 @@
 use std::io::Write;
 
 use color_eyre::eyre::Result;
-use watchexec::run;
+use watchexec::watch;
 
 mod args;
+mod handler;
 
 fn main() -> Result<()> {
     color_eyre::install()?;
-    let (args, loglevel) = args::get_args()?;
+    let handler = args::get_args()?;
 
     env_logger::Builder::new()
         .format(|buf, r| writeln!(buf, "*** {}", r.args()))
-        .filter(None, loglevel)
+        .filter(None, handler.log_level)
         .init();
 
-    run(args)?;
+    watch(&handler)?;
     Ok(())
 }
